@@ -106,7 +106,7 @@ int event_load(conf_t *conf, zone_t *zone)
 				log_zone_error(zone->name, "failed to parse zone file (%s)",
 					       knot_strerror(ret));
 			}
-			goto cleanup;
+			goto load_end;
 		}
 
 		// Save zonefile information.
@@ -194,7 +194,7 @@ int event_load(conf_t *conf, zone_t *zone)
 			zu_from_zf_conts = true;
 		} else {
 			// compute ZF diff and if success, apply it
-			ret = zone_update_from_differences(&up, conf, zone, NULL, zf_conts, UPDATE_INCREMENTAL, ignore_dnssec);
+			ret = zone_update_from_differences(&up, zone, NULL, zf_conts, UPDATE_INCREMENTAL, ignore_dnssec);
 		}
 	} else {
 		if (journal_conts != NULL && (zf_from != ZONEFILE_LOAD_WHOLE || zone->cat_members != NULL)) {
@@ -203,7 +203,7 @@ int event_load(conf_t *conf, zone_t *zone)
 				ret = zone_update_from_contents(&up, zone, journal_conts, UPDATE_HYBRID);
 			} else {
 				// load zone-in-journal, compute ZF diff and if success, apply it
-				ret = zone_update_from_differences(&up, conf, zone, journal_conts, zf_conts,
+				ret = zone_update_from_differences(&up, zone, journal_conts, zf_conts,
 				                                   UPDATE_HYBRID, ignore_dnssec);
 				if (ret == KNOT_ESEMCHECK || ret == KNOT_ERANGE) {
 					log_zone_warning(zone->name,
@@ -211,6 +211,7 @@ int event_load(conf_t *conf, zone_t *zone)
 					                 "ignoring zone file and loading from journal",
 					                 (ret == KNOT_ESEMCHECK ? "unupdated" : "decreased"));
 					zone_contents_deep_free(zf_conts);
+					zf_conts = NULL;
 					ret = zone_update_from_contents(&up, zone, journal_conts, UPDATE_HYBRID);
 				}
 			}
@@ -229,6 +230,8 @@ int event_load(conf_t *conf, zone_t *zone)
 			}
 		}
 	}
+
+load_end:
 	if (ret != KNOT_EOK) {
 		switch (ret) {
 		case KNOT_ENOENT:
