@@ -57,6 +57,12 @@ static int axfr_put_rrsets(knot_pkt_t *pkt, zone_node_t *node,
 			state->cur_rrset = i;
 			return ret;
 		}
+		if (pkt->size > KNOT_WIRE_PTR_MAX) {
+			// optimization: once the XFR DNS message is > 16 KiB, compression
+			// is limited. Better wrap to next message.
+			state->cur_rrset = i + 1;
+			return KNOT_ESPACE;
+		}
 	}
 
 	state->cur_rrset = 0;
@@ -105,7 +111,7 @@ static int axfr_query_check(knotd_qdata_t *qdata)
 {
 	NS_NEED_ZONE(qdata, KNOT_RCODE_NOTAUTH);
 	NS_NEED_AUTH(qdata, ACL_ACTION_TRANSFER);
-	NS_NEED_ZONE_CONTENTS(qdata, KNOT_RCODE_SERVFAIL);
+	NS_NEED_ZONE_CONTENTS(qdata);
 
 	return KNOT_STATE_DONE;
 }
@@ -185,6 +191,9 @@ int axfr_process_query(knot_pkt_t *pkt, knotd_qdata_t *qdata)
 			            knot_strerror(ret));
 			return KNOT_STATE_FAIL;
 		}
+	} else if (qdata->params->xdp_msg != NULL) {
+		qdata->rcode = KNOT_RCODE_SERVFAIL;
+		return KNOT_STATE_FAIL;
 	}
 
 	/* Reserve space for TSIG. */
